==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/resources/kotlin/inputs/DeploymentStackPropertiesActionOnUnmanageArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.resources.kotlin.inputs

import com.pulumi.azurenative.resources.inputs.DeploymentStackPropertiesActionOnUnmanageArgs.builder
import com.pulumi.azurenative.resources.kotlin.enums.DeploymentStacksDeleteDetachEnum
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Defines the behavior of resources that are not managed immediately after the stack is updated.
 * @property managementGroups Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
 * @property resourceGroups Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
 * @property resources Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
 */
public data class DeploymentStackPropertiesActionOnUnmanageArgs(
    public val managementGroups: Output<Either<String, DeploymentStacksDeleteDetachEnum>>? = null,
    public val resourceGroups: Output<Either<String, DeploymentStacksDeleteDetachEnum>>? = null,
    public val resources: Output<Either<String, DeploymentStacksDeleteDetachEnum>>,
) :
    ConvertibleToJava<com.pulumi.azurenative.resources.inputs.DeploymentStackPropertiesActionOnUnmanageArgs> {
    override fun toJava():
        com.pulumi.azurenative.resources.inputs.DeploymentStackPropertiesActionOnUnmanageArgs =
        com.pulumi.azurenative.resources.inputs.DeploymentStackPropertiesActionOnUnmanageArgs.builder()
            .managementGroups(
                managementGroups?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .resourceGroups(
                resourceGroups?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .resources(
                resources.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [DeploymentStackPropertiesActionOnUnmanageArgs].
 */
@PulumiTagMarker
public class DeploymentStackPropertiesActionOnUnmanageArgsBuilder internal constructor() {
    private var managementGroups: Output<Either<String, DeploymentStacksDeleteDetachEnum>>? = null

    private var resourceGroups: Output<Either<String, DeploymentStacksDeleteDetachEnum>>? = null

    private var resources: Output<Either<String, DeploymentStacksDeleteDetachEnum>>? = null

    /**
     * @param value Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
     */
    @JvmName("fewlayyckcngaqtb")
    public suspend
    fun managementGroups(`value`: Output<Either<String, DeploymentStacksDeleteDetachEnum>>) {
        this.managementGroups = value
    }

    /**
     * @param value Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
     */
    @JvmName("ydoxgrrsjigcudki")
    public suspend
    fun resourceGroups(`value`: Output<Either<String, DeploymentStacksDeleteDetachEnum>>) {
        this.resourceGroups = value
    }

    /**
     * @param value Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
     */
    @JvmName("dryeutwbgausjjrk")
    public suspend fun resources(`value`: Output<Either<String, DeploymentStacksDeleteDetachEnum>>) {
        this.resources = value
    }

    /**
     * @param value Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
     */
    @JvmName("qresfagfxronpgax")
    public suspend fun managementGroups(`value`: Either<String, DeploymentStacksDeleteDetachEnum>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.managementGroups = mapped
    }

    /**
     * @param value Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
     */
    @JvmName("elrghslolhxyeajr")
    public fun managementGroups(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeploymentStacksDeleteDetachEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.managementGroups = mapped
    }

    /**
     * @param value Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
     */
    @JvmName("gnlbgycjcyohcjqt")
    public fun managementGroups(`value`: DeploymentStacksDeleteDetachEnum) {
        val toBeMapped = Either.ofRight<String, DeploymentStacksDeleteDetachEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.managementGroups = mapped
    }

    /**
     * @param value Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
     */
    @JvmName("fwqplffydnjtvtag")
    public suspend fun resourceGroups(`value`: Either<String, DeploymentStacksDeleteDetachEnum>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroups = mapped
    }

    /**
     * @param value Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
     */
    @JvmName("aygucjwjyjrtbhgc")
    public fun resourceGroups(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeploymentStacksDeleteDetachEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceGroups = mapped
    }

    /**
     * @param value Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
     */
    @JvmName("lodlkwvhhiffuovy")
    public fun resourceGroups(`value`: DeploymentStacksDeleteDetachEnum) {
        val toBeMapped = Either.ofRight<String, DeploymentStacksDeleteDetachEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceGroups = mapped
    }

    /**
     * @param value Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
     */
    @JvmName("ifdhrdpekkpnsqfq")
    public suspend fun resources(`value`: Either<String, DeploymentStacksDeleteDetachEnum>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resources = mapped
    }

    /**
     * @param value Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
     */
    @JvmName("rabprciqcfmnrbyx")
    public fun resources(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeploymentStacksDeleteDetachEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resources = mapped
    }

    /**
     * @param value Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
     */
    @JvmName("tyjuwfpcntryymnr")
    public fun resources(`value`: DeploymentStacksDeleteDetachEnum) {
        val toBeMapped = Either.ofRight<String, DeploymentStacksDeleteDetachEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resources = mapped
    }

    internal fun build(): DeploymentStackPropertiesActionOnUnmanageArgs =
        DeploymentStackPropertiesActionOnUnmanageArgs(
            managementGroups = managementGroups,
            resourceGroups = resourceGroups,
            resources = resources ?: throw PulumiNullFieldException("resources"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/resources/kotlin/inputs/DeploymentStackPropertiesActionOnUnmanageArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.resources.kotlin.inputs

import com.pulumi.azurenative.resources.inputs.DeploymentStackPropertiesActionOnUnmanageArgs.builder
import com.pulumi.azurenative.resources.kotlin.enums.DeploymentStacksDeleteDetachEnum
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Defines the behavior of resources that are not managed immediately after the stack is updated.
 * @property managementGroups Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
 * @property resourceGroups Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
 * @property resources Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
 */
public data class DeploymentStackPropertiesActionOnUnmanageArgs(
    public val managementGroups: Output<Either<String, DeploymentStacksDeleteDetachEnum>>? = null,
    public val resourceGroups: Output<Either<String, DeploymentStacksDeleteDetachEnum>>? = null,
    public val resources: Output<Either<String, DeploymentStacksDeleteDetachEnum>>,
) :
    ConvertibleToJava<com.pulumi.azurenative.resources.inputs.DeploymentStackPropertiesActionOnUnmanageArgs> {
    override fun toJava():
        com.pulumi.azurenative.resources.inputs.DeploymentStackPropertiesActionOnUnmanageArgs =
        com.pulumi.azurenative.resources.inputs.DeploymentStackPropertiesActionOnUnmanageArgs.builder()
            .managementGroups(
                managementGroups?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .resourceGroups(
                resourceGroups?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .resources(
                resources.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [DeploymentStackPropertiesActionOnUnmanageArgs].
 */
@PulumiTagMarker
public class DeploymentStackPropertiesActionOnUnmanageArgsBuilder internal constructor() {
    private var managementGroups: Output<Either<String, DeploymentStacksDeleteDetachEnum>>? = null

    private var resourceGroups: Output<Either<String, DeploymentStacksDeleteDetachEnum>>? = null

    private var resources: Output<Either<String, DeploymentStacksDeleteDetachEnum>>? = null

    /**
     * @param value Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
     */
    @JvmName("mhvgrsnbhrkerouk")
    public suspend
    fun managementGroups(`value`: Output<Either<String, DeploymentStacksDeleteDetachEnum>>) {
        this.managementGroups = value
    }

    /**
     * @param value Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
     */
    @JvmName("mgymdnuauxkgecmw")
    public suspend
    fun resourceGroups(`value`: Output<Either<String, DeploymentStacksDeleteDetachEnum>>) {
        this.resourceGroups = value
    }

    /**
     * @param value Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
     */
    @JvmName("sieugwhsucctsfxa")
    public suspend fun resources(`value`: Output<Either<String, DeploymentStacksDeleteDetachEnum>>) {
        this.resources = value
    }

    /**
     * @param value Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
     */
    @JvmName("herhofstjpkaadqg")
    public suspend fun managementGroups(`value`: Either<String, DeploymentStacksDeleteDetachEnum>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.managementGroups = mapped
    }

    /**
     * @param value Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
     */
    @JvmName("yhjaudayrsmhsgwi")
    public fun managementGroups(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeploymentStacksDeleteDetachEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.managementGroups = mapped
    }

    /**
     * @param value Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
     */
    @JvmName("bwedvixxdaqfofty")
    public fun managementGroups(`value`: DeploymentStacksDeleteDetachEnum) {
        val toBeMapped = Either.ofRight<String, DeploymentStacksDeleteDetachEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.managementGroups = mapped
    }

    /**
     * @param value Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
     */
    @JvmName("ugotegviisghdhjj")
    public suspend fun resourceGroups(`value`: Either<String, DeploymentStacksDeleteDetachEnum>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroups = mapped
    }

    /**
     * @param value Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
     */
    @JvmName("oeoriqnasmepqinh")
    public fun resourceGroups(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeploymentStacksDeleteDetachEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceGroups = mapped
    }

    /**
     * @param value Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
     */
    @JvmName("vodqbbxslvglwqss")
    public fun resourceGroups(`value`: DeploymentStacksDeleteDetachEnum) {
        val toBeMapped = Either.ofRight<String, DeploymentStacksDeleteDetachEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceGroups = mapped
    }

    /**
     * @param value Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
     */
    @JvmName("powdlriujbysobde")
    public suspend fun resources(`value`: Either<String, DeploymentStacksDeleteDetachEnum>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resources = mapped
    }

    /**
     * @param value Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
     */
    @JvmName("hxwqyqwhkjpxycga")
    public fun resources(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeploymentStacksDeleteDetachEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resources = mapped
    }

    /**
     * @param value Specifies the action that should be taken on the resource when the deployment stack is deleted. Delete will attempt to delete the resource from Azure. Detach will leave the resource in it's current state.
     */
    @JvmName("pyhsyiimmsypiyfm")
    public fun resources(`value`: DeploymentStacksDeleteDetachEnum) {
        val toBeMapped = Either.ofRight<String, DeploymentStacksDeleteDetachEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resources = mapped
    }

    internal fun build(): DeploymentStackPropertiesActionOnUnmanageArgs =
        DeploymentStackPropertiesActionOnUnmanageArgs(
            managementGroups = managementGroups,
            resourceGroups = resourceGroups,
            resources = resources ?: throw PulumiNullFieldException("resources"),
        )
}
